# PastyPY

[![pytest](https://github.com/zevaryx/pastypy/actions/workflows/pytest.yml/badge.svg)](https://github.com/zevaryx/pastypy/actions/workflows/pytest.yml) [![codecov](https://codecov.io/gh/zevaryx/pastypy/branch/main/graph/badge.svg?token=IPC1OMI36K)](https://codecov.io/gh/zevaryx/pastypy)

A Python wrapper around [Pasty](https://github.com/lus/pasty) written by lus

## Features

- Full API coverage
- `asyncio` support with `pastypy.AsyncPaste`
- Encryption support

## Examples

See [examples](https://github.com/zevaryx/pastypy/tree/main/examples) for usage and examples
